pub struct Server<F, const N: usize> {
pub now: F,
pub range_start: Ipv4Addr,
pub range_end: Ipv4Addr,
pub leases: LinearMap<Ipv4Addr, Lease, N>,
}Expand description
A simple DHCP server. The server is unaware of the IP/UDP transport layer and operates purely in terms of packets represented as Rust slices.
Fields
now: Frange_start: Ipv4Addrrange_end: Ipv4Addrleases: LinearMap<Ipv4Addr, Lease, N>Implementations
Sourceimpl<F, const N: usize> Server<F, N>
impl<F, const N: usize> Server<F, N>
Sourcepub const fn new(now: F, ip: Ipv4Addr) -> Self
pub const fn new(now: F, ip: Ipv4Addr) -> Self
Create a new DHCP server.
Arguments
now: A closure that returns the current time in seconds since some epoch.ip: The IP address of the server.
pub fn handle_request<'o>( &mut self, opt_buf: &'o mut [DhcpOption<'o>], server_options: &'o ServerOptions<'_>, request: &Packet<'_>, ) -> Option<Packet<'o>>